==> genie.libs.parser-24.7-py3-none-any.whl: genie/libs/parser/iosxe/tests/ShowStackPowerDetail/cli/equal/golden_output1_expected.py <==
expected_output = {
        "power_stack":{
            "Powerstack-Ring-1":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":235,
                "available_power":865,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "stack_ecomode":"Enable",
                    "switch":{
                        3:{
                            "power_budget":955,
                            "power_allocated":235,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "ecomode":"FEP B auto offlined",
                            "capacity":"350"
                        }
                    }
                }
            },
            "Powerstack-Ring-1-1":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":575,
                "available_power":525,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "stack_ecomode":"Enable",
                    "switch":{
                        1:{
                            "power_budget":1100,
                            "power_allocated":575,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "ecomode":"FEP B auto offlined",
                            "capacity":"1100"
                        }
                    }
                }
            },
            "Powerstack-Ring-1-2":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":365,
                "available_power":735,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "stack_ecomode":"Enable",
                    "switch":{
                        2:{
                            "power_budget":1100,
                            "power_allocated":365,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "ecomode":"FEP B auto offlined",
                            "capacity":"1100"
                        }
                    }
                }
            }
        }
    }

==> genie.libs.parser-24.11-py3-none-any.whl: genie/libs/parser/iosxe/tests/ShowStackPowerDetail/cli/equal/golden_output1_expected.py <==
expected_output = {
        "power_stack":{
            "Powerstack-Ring-1":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":235,
                "available_power":865,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "Stack_total_input_power": 4400,
                    "power_supply_auto_off":"Enable",
                    "switch":{
                        3:{
                            "power_budget":955,
                            "power_allocated":235,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "auto_off":"FEP B auto offlined",
                            "capacity":"350"
                        }
                    }
                }
            },
            "Powerstack-Ring-1-1":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":575,
                "available_power":525,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "Stack_total_input_power": 4400,
                    "power_supply_auto_off":"Enable",
                    "switch":{
                        1:{
                            "power_budget":1100,
                            "power_allocated":575,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "auto_off":"FEP B auto offlined",
                            "capacity":"1100"
                        }
                    }
                }
            },
            "Powerstack-Ring-1-2":{
                "mode":"SP-PS",
                "topology":"Stndaln",
                "total_power":1100,
                "reserved_power":0,
                "allocated_power":365,
                "available_power":735,
                "switch_num":1,
                "power_supply_num":1,
                "power_stack_detail":{
                    "stack_mode":"Power sharing",
                    "stack_topology":"Standalone",
                    "Stack_total_input_power": 4400,
                    "power_supply_auto_off":"Enable",
                    "switch":{
                        2:{
                            "power_budget":1100,
                            "power_allocated":365,
                            "low_port_priority_value":22,
                            "high_port_priority_value":13,
                            "switch_priority_value":4,
                            "port_1_status":"Shut",
                            "port_2_status":"Shut",
                            "neighbor_on_port_1":"0000.0000.0000",
                            "neighbor_on_port_2":"0000.0000.0000",
                            "auto_off":"FEP B auto offlined",
                            "capacity":"1100"
                        }
                    }
                }
            }
        }
    }
